<?php

namespace GiveSquare\Addon\Migrations;

use Give\Helpers\Call;
use GiveSquare\Addon\Log\Log;
use GiveSquare\Addon\Migration\Migration;
use GiveSquare\GatewayConnect\Actions\RenewSquareAccessToken;

/**
 * @since 1.2.0
 */
class RenewLiveAndSandboxSquareAccessToken extends Migration
{
    /**
     * @since 1.2.0
     */
    public static function id(): string
    {
        return 'renew-live-and-sandbox-square-access-token';
    }

    /**
     * @since 1.2.0
     */
    public static function title(): string
    {
        return esc_html__('Renew line and sandbox square access token', 'give-square');
    }

    /**
     * @since 1.2.0
     * @return string
     */
    public static function timestamp(): string
    {
        return '2022-05-27';
    }

    /**
     * @since 1.2.0
     */
    public function run()
    {
        $accountModes = [
            'live',
            'test'
        ];

        foreach ($accountModes as $accountMode) {
            try {
                Call::invoke(RenewSquareAccessToken::class, $accountMode);
            } catch (\Exception $exception) {
                Log::error(
                    sprintf(
                        '%1$s square account renew access token failure',
                        'test' === $accountMode ?
                            esc_html__('Sandbox', 'give-square') :
                            esc_html__('Live', 'give-square')
                    ),
                    ['Error' => $exception->getMessage()]
                );
            }
        }
    }
}
