<?php

namespace GiveSquare\GatewayConnect\Actions;

use Give\Framework\Exceptions\Primitives\Exception;
use GiveSquare\GatewayConnect\Exceptions\AccountNotFoundException;
use GiveSquare\GatewayConnect\Modals\SquareAccount;

/**
 * @since 1.2.0
 */
class RenewSquareAccessToken
{
    /**
     * @since 1.2.0
     *
     * @throws Exception
     */
    public function __invoke(string $mode)
    {
        $squareAccount = SquareAccount::make($mode);

        if (!$squareAccount->isConnected()) {
            throw new Exception(
                sprintf(
                    '%1$s square account is not connected. Please connect square account to generate access token.',
                    $squareAccount->getAccountType(true)
                )
            );
        }

        try {
            $squareAccount->renewAccessToken();
        } catch (AccountNotFoundException $exception) {
            $squareAccount->disconnectAccount();
            throw $exception;
        }
    }
}
