<?php

namespace GiveSquare\GatewayConnect\Admin;

use Give\Framework\Exceptions\Primitives\Exception;
use GiveSquare\GatewayConnect\Modals\SquareAccount;

class Notices
{
    /**
     * @since 2.0.0
     * @throws Exception
     */
    public function enableSubscriptions()
    {
        $mode = give_is_test_mode() ? 'test' : 'live';
        $squareAccount = SquareAccount::make($mode);

        $notice = [
            'id' => 'give-square-enable-subscriptions',
            'type' => 'warning',
            'dismissible_type' => 'user',
            'dismiss_interval' => 'permanent',
        ];

        if ( ! $squareAccount->isConnected()) {
            return;
        }

        if ($squareAccount->validateScopes() && $squareAccount->isWebhookSetup()) {
            return;
        }

        $notice['description'] = sprintf(__('Recurring Donations are now possible using the Square payment gateway. To begin accepting recurring donations, disconnect and reconnect your Square account, <a href="%s" target="_blank">configure your account webhooks in the settings</a>, and install or update the <a href="%s" target="_blank">GiveWP Recurring Donations add-on »</a>',
            'give-square'),
            admin_url('/edit.php?post_type=give_forms&page=give-settings&tab=gateways&section=square-settings'),
            'https://givewp.com/addons/recurring-donations/');

        if ($squareAccount->validateScopes() && ! $squareAccount->isWebhookSetup()) {
            $notice['description'] = sprintf(__('Recurring Donations are now possible using the Square payment gateway. To begin accepting recurring donations, <a href="%s" target="_blank">configure your account webhooks in the settings</a> and install or update the <a href="%s" target="_blank">GiveWP Recurring Donations add-on »</a>',
                'give-square'),
                admin_url('/edit.php?post_type=give_forms&page=give-settings&tab=gateways&section=square-settings'),
                'https://givewp.com/addons/recurring-donations/');
        }

        Give()->notices->register_notice($notice);
    }
}
