<?php

namespace GiveSquare\GatewayConnect\Api;

use Give\Framework\Exceptions\Primitives\Exception;
use GiveSquare\Square\Api\Exceptions\ApiRequestException;
use GiveSquare\Square\Api\Traits\ApiRequestHelpers;
use stdClass;

/**
 * @since 2.0.0
 *
 * @see https://developer.squareup.com/reference/square/webhook-subscriptions-api/create-webhook-subscription
 */
class CreateWebhookSubscription
{
    use ApiRequestHelpers;

    /**
     * @since 2.0.0
     *
     * @throws ApiRequestException|Exception
     */
    public function __invoke(array $requestData, string $mode, string $personalAccessToken): stdClass
    {
        $requestArgs['headers'] = $this->getApiRequestHeaders();
        $requestArgs['body'] = json_encode($requestData);

        /**
         * Because Webhook subscriptions are owned by the application and not any one seller, you cannot use OAuth
         * Access Tokens with the Webhook Subscription API. You must use the application’s personal access token.
         *
         * @see https://developer.squareup.com/docs/webhooks/webhook-subscriptions-api
         */
        $requestArgs['headers']['Authorization'] = 'Bearer ' . $personalAccessToken;

        $response = wp_remote_post(
            $this->getApiRequestUrl('v2/webhooks/subscriptions', $mode),
            $requestArgs
        );

        if (is_wp_error($response)) {
            throw new Exception("Square API request error. Error: {$response->get_error_message()}");
        }

        $webhook = $this->getResponseOrThrowApiException($response);

        return $webhook->subscription;
    }
}
