<?php

namespace GiveSquare\GatewayConnect\Api;

use GiveSquare\GatewayConnect\Exceptions\RetrieveTokenException;
use GiveSquare\GatewayConnect\Exceptions\ScopesNotFoundException;
use stdClass;
use WP_Error;

/**
 * @since 2.0.0
 */
class RetrieveTokenStatus
{
    /**
     * @since 2.0.1 Use $responseBody instead of $response->get_error_message() on the ScopesNotFoundException
     * @since      2.0.0
     *
     * @throws ScopesNotFoundException|RetrieveTokenException
     */
    public function __invoke(string $token = '', string $mode = ''): stdClass
    {
        if ( ! function_exists('give_square_get_access_token')) {
            require_once GIVE_SQUARE_PLUGIN_DIR . '/includes/helpers.php';
        }

        if (empty($token)) {
            $token = give_square_get_access_token();
        }

        if (empty($mode)) {
            $mode = give_is_test_mode() ? 'test' : 'live';
        }

        $remoteUrl = give_square_connect_server_url(
            sprintf('/square/token-status?token=%1$s&mode=%2$s', $token, $mode)
        );

        $response = wp_remote_post($remoteUrl);

        $this->validateWpErrorInResponse($response);

        $responseBody = wp_remote_retrieve_body($response);

        if (strpos($responseBody, "scopes") === false) {
            throw new ScopesNotFoundException(
                esc_html__(
                    sprintf(
                        'Unable to retrieve Square token scopes. Please reconnect with your Square account and then try again. Square API Response:  %1$s',
                        $responseBody
                    )
                )
            );
        }

        return json_decode($responseBody);
    }

    /**
     * @since 2.0.0
     *
     * @param array|WP_Error $response
     *
     * @throws RetrieveTokenException
     */
    private function validateWpErrorInResponse($response)
    {
        if (is_wp_error($response)) {
            throw new RetrieveTokenException(
                esc_html__(
                    sprintf(
                        'Retrieve Square token status failed. Error:  %1$s',
                        $response->get_error_message()
                    )
                )
            );
        }
    }
}
