<?php

namespace GiveSquare\PaymentGateway\Actions;

use Give\Donations\Models\Donation;
use Give\Framework\Exceptions\Primitives\Exception;
use GiveSquare\Square\Api\CreatePayment;

/**
 * @since 1.2.0
 */
class CreateSquarePayment
{
    /**
     * @since 1.2.0
     * @throws Exception
     */
    public function __invoke(Donation $donation, $sourceId): string
    {
        $squareLocationId = (new GetSquareLocationId())($donation);
        $squareCustomerId = (new GetSquareCustomerId())($donation);
        $idempotencyKey = (new GetIdempotencyKey())($donation);
        $squarePaymentNote = sprintf(
        /* translators: 1. Give Donation Form Title. */
            esc_html__('Donation to %1$s', 'give-square'),
            mb_strlen($donation->formTitle) > 42 ? mb_substr(
                    $donation->formTitle,
                    0,
                    42
                ) . '...' : $donation->formTitle
        );

        $requestData = [
            'idempotency_key' => $idempotencyKey,
            'amount_money' => [
                'amount' => (int)$donation->amount->formatToMinorAmount(),
                'currency' => $donation->amount->getCurrency()->getCode()
            ],
            'source_id' => $sourceId,
            'autocomplete' => true,
            'customer_id' => $squareCustomerId,
            'location_id' => $squareLocationId,
            'reference_id' => (string)$donation->id,
            'buyer_email_address' => $donation->email,
            'note' => $squarePaymentNote,
        ];

        // If billing address is enabled, then attach it to payment request.
        if (give_is_setting_enabled(give_get_option('give_square_collect_billing_details', false))) {
            $requestData['address_line_1'] = $donation->billingAddress->address1;
            $requestData['address_line_2'] = $donation->billingAddress->address2;
            $requestData['sublocality'] = $donation->billingAddress->city;
            $requestData['locality'] = $donation->billingAddress->state;
            $requestData['country'] = $donation->billingAddress->country;
            $requestData['postal_code'] = $donation->billingAddress->zip;
        }

        return (new CreatePayment())($requestData)->id;
    }
}
