<?php

namespace GiveSquare\Square\Api\Exceptions;

use Give\Framework\Exceptions\Primitives\Exception;
use stdClass;

/**
 * @since 1.2.0
 */
class ApiRequestException extends Exception
{
    /**
     * @since 1.2.0
     * Square error object https://developer.squareup.com/reference/square/payments-api/create-payment#response-body
     * @var stdClass
     */
    private $squareApiResponse;

    /**
     * @since 1.2.0
     */
    public function __construct(stdClass $squareApiResponse)
    {
        $this->squareApiResponse = $squareApiResponse;
        parent::__construct();
    }

    /**
     * @since 1.2.0
     */
    public function getSquareErrorMessage(): string
    {
        return $this->getSquareErrorDetail() ?? $this->getSquareErrorCode();
    }

    /**
     * @since 1.2.0
     */
    public function getSquareError(): stdClass
    {
        return $this->squareApiResponse->errors[0];
    }

    /**
     * @since 1.2.0
     */
    public function getSquareErrorCode(): string
    {
        return $this->getSquareError()->code;
    }

    /**
     * @since 1.2.0
     */
    public function getSquareErrorField(): string
    {
        return $this->getSquareError()->field;
    }

    /**
     * @since 1.2.0
     */
    public function getSquareErrorCategory(): string
    {
        return $this->getSquareError()->category;
    }

    /**
     * @since 1.2.0
     */
    public function getSquareErrorDetail(): string
    {
        return $this->getSquareError()->detail;
    }

    /**
     * @since 1.2.0
     */
    public function getSquarePaymentId(): string
    {
        return property_exists($this->squareApiResponse, 'payment') ?
            $this->squareApiResponse->payment->id :
            '';
    }
}
