<?php

namespace GiveSquare\Square\Api\Traits;

use GiveSquare\Square\Api\Exceptions\ApiRequestException;

trait ApiRequestHelpers
{
    /**
     * @since 1.2.0
     */
    protected function getApiRequestUrl(string $urlPrefix, string $mode = 'default'): string
    {
        $host = give_square_get_host($mode);

        return "https://connect.$host/$urlPrefix";
    }

    /**
     * @since 1.2.0
     */
    protected function getApiRequestHeaders(): array
    {
        return [
            'Authorization' => 'Bearer ' . give_square_get_access_token(),
            'Square-Version' => '2023-01-19',
            'Content-Type' => 'application/json',
        ];
    }

    /**
     * @since 1.2.0
     * @throws ApiRequestException
     */
    protected function getResponseOrThrowApiException(array $response): \stdClass
    {
        $response = json_decode(wp_remote_retrieve_body($response));

        if (property_exists($response, 'errors')) {
            throw new ApiRequestException($response);
        }

        return $response;
    }
}
